# Contributing

Thank you for your interest in Mixed Pickles! At this time, I am not accepting external contributions to this project.

If you have questions, suggestions, or find a bug, feel free to open an issue for discussion.
